@@ -13,9 +13,6 @@ const (
 	// For primary/secondary replication.
 	EndpointGetSecondaryTreeHead = Endpoint("get-secondary-tree-head")
 
-	// Old Sigsum witness api.
-	EndpointAddTreeHead = Endpoint("add-tree-head")
-	EndpointGetTreeSize = Endpoint("get-tree-size/")
 	// Witness api.
 	EndpointAddCheckpoint = Endpoint("add-checkpoint")
 )
